Stan Math Library: stan/math/prim/scal/prob/rayleigh_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

rayleigh_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_RAYLEIGH_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_RAYLEIGH_RNG_HPP
3
4 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
5 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
6 #include <stan/math/prim/scal/err/check_not_nan.hpp>
7 #include <stan/math/prim/scal/err/check_positive.hpp>
8 #include <stan/math/prim/scal/fun/log1m.hpp>
9 #include <stan/math/prim/scal/fun/square.hpp>
10 #include <stan/math/prim/scal/fun/value_of.hpp>
11 #include <stan/math/prim/scal/meta/length.hpp>
12 #include <stan/math/prim/scal/fun/constants.hpp>
13 #include <stan/math/prim/scal/meta/include_summand.hpp>
14 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
15 #include <boost/random/uniform_real_distribution.hpp>
16 #include <boost/random/variate_generator.hpp>
17
18 namespace stan {
19
20 namespace math {
21
22 template <class RNG>
23 inline double
24 rayleigh_rng(const double sigma,
25 RNG& rng) {
26 using boost::variate_generator;
27 using boost::random::uniform_real_distribution;
28
29 static const char* function("stan::math::rayleigh_rng");
30
31 using stan::math::check_positive;
32
33 check_positive(function, "Scale parameter", sigma);
34
35 variate_generator<RNG&, uniform_real_distribution<> >
36 uniform_rng(rng, uniform_real_distribution<>(0.0, 1.0));
37 return sigma * std::sqrt(-2.0 * std::log(uniform_rng()));
38 }
39 }
40 }
41 #endif
check_not_nan.hpp
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
check_positive.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::rayleigh_rng
double rayleigh_rng(const double sigma, RNG &rng)
Definition: rayleigh_rng.hpp:24
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
square.hpp
include_summand.hpp
check_nonnegative.hpp
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
stan::math::uniform_rng
double uniform_rng(const double alpha, const double beta, RNG &rng)
Definition: uniform_rng.hpp:21
VectorBuilder.hpp
log1m.hpp
length.hpp
constants.hpp
value_of.hpp
check_consistent_sizes.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.